==> cordova-sqlite-evcore-extbuild-free-0.13.0.tgz: package/LICENSE.md <==
# License

This plugin version is available under GPL v3 (http://www.gnu.org/licenses/gpl.txt) or commercial license. Contact for commercial license: sales@litehelpers.net

This plugin version is based on Cordova-sqlite-storage (https://github.com/litehelpers/Cordova-sqlite-storage), available under MIT license (all platforms) or Apache 2.0 license (Android and Windows).

The iOS/macOS platform version is based on Phonegap-SQLitePlugin by @davibe (Davide Bertola <dade@dadeb.it>) and @joenoon (Joe Noon <joenoon@gmail.com>) (MIT license).

The iOS/macOS platform version includes and uses PSPDFThreadSafeMutableDictionary (PSPDFThreadSafeMutableDictionary.m <https://gist.github.com/steipete/5928916>) by @steipete (<https://gist.github.com/steipete>) (MIT license).

The Windows platform version includes SQLite3-WinRT by @doo (doo GmbH) under MIT License.

Other components:

sqlite3-regexp-cached - adapted by @brodybits (Christopher J. Brody), based on sqlite3-pcre (http://git.altlinux.org/people/at/packages/?p=sqlite3-pcre.git) by Alexey Tourbin, public domain

sqlite3-base64 by @brodybits (Christopher J. Brody), Unlicense (http://unlicense.org/ - public domain)

libb64-encode - based on libb64 (http://libb64.sourceforge.net/) by Chris Venter, public domain

MIT or Apache 2.0

### SQLite3-WinRT

by @doo (doo GmbH)

MIT License

### sqlite3-regexp-cached

Based on <http://git.altlinux.org/people/at/packages/?p=sqlite3-pcre.git> by Alexey Tourbin, public domain

### sqlite3-base64

Unlicense (public domain)

### libb64-encode

Based on <http://libb64.sourceforge.net/> by Chris Venter, public domain)

### SQLite3

public domain

==> cordova-sqlite-evcore-extbuild-free-0.17.0.tgz: package/LICENSE.md <==
# License

This plugin version is available under GPL v3 (http://www.gnu.org/licenses/gpl.txt) or commercial license. Contact for commercial license: sales@litehelpers.net

This plugin version is based on Cordova-sqlite-storage (https://github.com/litehelpers/Cordova-sqlite-storage), available under MIT license (all platforms) or Apache 2.0 license (Android and Windows).

The iOS/macOS platform version is based on Phonegap-SQLitePlugin by @davibe (Davide Bertola <dade@dadeb.it>) and @joenoon (Joe Noon <joenoon@gmail.com>) (MIT license).

The iOS/macOS platform version includes and uses PSPDFThreadSafeMutableDictionary (PSPDFThreadSafeMutableDictionary.m <https://gist.github.com/steipete/5928916>) by @steipete (<https://gist.github.com/steipete>) (MIT license).

The Windows platform version includes SQLite3-WinRT by @doo (doo GmbH) under MIT License.

Other components:

sqlite3-regexp-cached - adapted by @brodybits (Christopher J. Brody), based on sqlite3-pcre (http://git.altlinux.org/people/at/packages/?p=sqlite3-pcre.git) by Alexey Tourbin, public domain

sqlite3-base64 by @brodybits (Christopher J. Brody), Unlicense (http://unlicense.org/ - public domain)

libb64-core - based on libb64 (http://libb64.sourceforge.net/) by Chris Venter, public domain

MIT or Apache 2.0

### SQLite3-WinRT

by @doo (doo GmbH)

MIT License

### sqlite3-regexp-cached

Based on <http://git.altlinux.org/people/at/packages/?p=sqlite3-pcre.git> by Alexey Tourbin, public domain

### sqlite3-base64

Unlicense (public domain)

### libb64-core

Based on <http://libb64.sourceforge.net/> by Chris Venter, public domain)

### SQLite3

public domain
